@@ -180,12 +180,12 @@
             sep="", file=file, append=TRUE)
     }
 
-    if (inla.one.of(family, "gev2")) {
-        c.gev2 = control$control.gev2
-        nms = names(c.gev2)
-        for (i in seq_along(c.gev2)) {
+    if (inla.one.of(family, "bgev")) {
+        c.bgev = control$control.bgev
+        nms = names(c.bgev)
+        for (i in seq_along(c.bgev)) {
             ## need this, as the xi.range is a vector of length 2
-            cat("gev2.", nms[i], " = ", paste(as.numeric(c.gev2[[i]]), collapse = " "),
+            cat("bgev.", nms[i], " = ", paste(as.numeric(c.bgev[[i]]), collapse = " "),
                 "\n", sep="", file=file, append=TRUE)
         }
     }
@@ -236,6 +236,13 @@
         }
     }
 
+    a = control$control.link$a
+    if (inla.one.of(lmod, c("loga"))) {
+        if (is.null(a) || !is.numeric(a) || (a <= 0  || a > 1))
+            stop(paste("For link-model:", lmod, ", the argument 'a' must be given, and 0 < a <= 1"))
+        cat("link.a = ", a, "\n", file = file,  append = TRUE)
+    }
+
     inla.write.hyper(control$control.link$hyper, file, prefix = "link.", data.dir = dirname(file))
     if (!is.null(link.covariates)) {
         if (!is.matrix(link.covariates)) {
@@ -851,6 +858,23 @@
     if (!is.null(inla.spec$cmin)) {
         cat("cmin = ", inla.spec$cmin, "\n", file = file, append = TRUE)
     }
+    if (!is.null(inla.spec$b.strategy)) {
+        b = inla.spec$b.strategy
+        if (is.character(b)) {
+            ## use the same enum mapping as in GMRFLibP.h for INLA_B_STRATEGY_SKIP and _KEEP
+            if (inla.strcasecmp(b, "skip")) {
+                b = 0
+            } else if (inla.strcasecmp(b, "keep")) {
+                b = 1
+            } else {
+                stop("control.inla$b.strategy must be 'keep' or 'skip'.")
+            }
+        } else {
+            b = as.integer(b)
+            stopifnot(any(b == 0:1))
+        }
+        cat("b.strategy = ", b, "\n", file = file, append = TRUE)
+    }
     if (!is.null(inla.spec$step.factor)) {
         cat("nr.step.factor = ", inla.spec$step.factor, "\n", file = file, append = TRUE)
     }
