@@ -180,8 +180,8 @@
 `inla.only.for.developers` = function()
 {
     if (!(Sys.getenv("USER") %in%
-                    c("hrue", "martino", "finnkrl", "finn",
-                      "danielsimpson", "rieblera", "ariebler", "fuglstad")))
+          c("hrue", "rueh", "martino", "finnkrl", "finn", "cristian", "chiuchc", 
+            "danielsimpson", "rieblera", "ariebler", "fuglstad")))
         warning("This function is for developers only...")
     return (invisible())
 }
@@ -193,8 +193,8 @@
 
     inla.only.for.developers()
 
-    if (Sys.getenv("USER") %in% c("hrue")) {
-        dir.default = "~/p/inla/google-code/inla/rinla/R"
+    if (Sys.getenv("USER") %in% c("hrue", "rueh")) {
+        dir.default = "~/p/inla/r-inla/rinla/R"
         bin.default = "~/p/inla/work/local/bin"
     } else if (Sys.getenv("USER") %in% c("elias")) {
         dir.default = "~/inla-project/source/inla/rinla/R"
@@ -205,6 +205,9 @@
     } else if (Sys.getenv("USER") %in% c("rieblera", "ariebler")) {
         dir.default = "~/inla/rinla/R"
         bin.default = "~/local/bin"
+    } else if (Sys.getenv("USER") %in% c("cristian", "chiuchc")) {
+        dir.default = "~/Desktop/r-inla/rinla/R"
+        bin.default = "~/local/bin"
     } else {
         dir.default = "~/hg/inla/rinla/R"
         bin.default = "~/local/bin"
@@ -1104,3 +1107,24 @@
 }
 
 
+`inla.sn.par` = function(mean, variance, skew)
+{
+    ## return the parameters in the skew-normal for the given three moments. the parameters are
+    ## like those given in the sn-package. based on code written by CC.
+    
+    sn.map <- function(mu, variance, skew) {
+        delta <- sign(skew)*sqrt((pi/2)*(abs(skew)^(2/3)/(((4 - pi)/2)^(2/3)+abs(skew)^(2/3))))
+        alpha <- delta/sqrt(1-delta^2)
+        xi <- mu - delta*sqrt((2*variance)/(pi - 2*delta^2))
+        omega <- sqrt((pi*variance)/(pi - 2*delta^2))
+        return(list(xi = xi, omega = omega, alpha = alpha))
+    }
+
+    skew.max <- 0.99
+    skew[which(is.na(skew))] <- 0
+    if (any(abs(skew) > skew.max)) {
+        skew <- pmax(-skew.max, pmin(skew.max, skew))
+        warning(paste0("One or more abs(skewness) are too high. Coerced to be ", skew.max))
+    }
+    return (sn.map(mean, variance, skew))
+}
