@@ -49,11 +49,11 @@
                                    "date",
                                    "bdate"))
 {
-    rinla.hgid =  inla.trim("Version_20.04.18")
-    inla.hgid  =  inla.trim("Version_20.04.18")
-    date       =  inla.trim("Sat Apr 18 20:08:00 +03 2020")
-    bdate      =  inla.trim("202004182008")
-    version      =  inla.trim("20.04.18")
+    rinla.hgid =  inla.trim("Version_20.05.12")
+    inla.hgid  =  inla.trim("Version_20.05.12")
+    date       =  inla.trim("Thu May 14 14:27:30 +03 2020")
+    bdate      =  inla.trim("202005141427")
+    version      =  inla.trim("20.05.12")
     what = match.arg(what)
 
     if (what %in% c("default", "info")) {
